@@ -586,6 +586,29 @@ bas.glm <- function(formula, family = binomial(link = "logit"),
 
   # drop null model if it is present
   if (betaprior$family == "Jeffreys" & (min(result$size) == 1)) result <- .drop.null.bas(result)
+  
+  # github issue #74. drop models with zero prior probability
+  
+  if (any(result$priorprobs == 0)) {
+    drop.models = result$priorprobs != 0
+    
+    result$mle = result$mle[drop.models]
+    result$mle.se = result$mle.se[drop.models]
+    result$mse = result$mse[drop.models]
+    result$which = result$which[drop.models]
+    result$freq = result$freq[drop.models]
+    result$shrinkage = result$shrinkage[drop.models]
+    result$R2 = result$R2[drop.models]
+    result$logmarg = result$logmarg[drop.models]
+    result$df = result$df[drop.models]
+    result$size = result$size[drop.models]
+    result$Q = result$Q[drop.models]
+    result$rank = result$rank[drop.models]
+    result$sampleprobs = result$sampleprobs[drop.models]
+    result$postprobs = result$postprobs[subset = drop.models]
+    result$priorprobs = result$priorprobs[subset = drop.models]
+    result$n.models = length(result$postprobs)
+  }
 
   if (method == "MCMC") {
     result$postprobs.MCMC <- result$freq / sum(result$freq)
